@@ -5,7 +5,7 @@ import xarray as xr
 
 try:
     from jaws import common, sunposition
-except ImportError:
+except:
     import common, sunposition
 
 
@@ -72,9 +72,10 @@ def get_time_and_sza(args, input_file, latitude, longitude, dataframe):
             idx += 1
 
         seconds = (dtime - dtime_1970).total_seconds()
-        time.append(seconds)
         bounds.append((seconds - common.seconds_in_hour, seconds))
 
+        time.append(seconds-common.seconds_in_half_hour)
+        dtime = datetime.utcfromtimestamp(seconds - common.seconds_in_half_hour)
         sza.append(sunposition.sunpos(dtime, latitude, longitude, 0)[1])
 
     return time, bounds, sza, year, month, day, hour, day_of_year
@@ -114,6 +115,6 @@ def aaws2nc(args, input_file, output_file, stations):
     comp_level = args.dfl_lvl
 
     common.load_dataset_attributes('aaws', ds, args)
-    encoding = common.get_encoding('aaws', common.get_fillvalue(args), comp_level)
+    encoding = common.get_encoding('aaws', common.get_fillvalue(args), comp_level, args)
 
     common.write_data(args, ds, output_file, encoding)
