@@ -6,9 +6,9 @@ import pandas as pd
 import xarray as xr
 
 try:
-    from jaws import common, sunposition
-except ImportError:
-    import common, sunposition
+    from jaws import common, sunposition, clearsky, tilt_angle, fsds_adjust
+except:
+    import common, sunposition, clearsky, tilt_angle, fsds_adjust
 
 
 def init_dataframe(args, input_file, sub_type):
@@ -50,7 +50,7 @@ def get_time_and_sza(args, dataframe, longitude, latitude):
     seconds_in_hour = common.seconds_in_hour
     num_rows = dataframe['year'].size
 
-    month, day, time, time_bounds, sza = ([0] * num_rows for _ in range(5))
+    month, day, minutes, time, time_bounds, sza, az = ([0] * num_rows for _ in range(7))
 
     hour = dataframe['day_of_year']
     hour = [round(i - int(i), 3) * hour_conversion for i in hour]
@@ -75,9 +75,14 @@ def get_time_and_sza(args, dataframe, longitude, latitude):
 
         time_bounds[idx] = (time[idx] - seconds_in_hour, time[idx])
 
-        sza[idx] = sunposition.sunpos(temp_dtime, latitude, longitude, 0)[1]
+        time[idx] = time[idx] - common.seconds_in_half_hour
+        temp_dtime = datetime.utcfromtimestamp(time[idx])
 
-    return hour, month, day, time, time_bounds, sza
+        solar_angles = sunposition.sunpos(temp_dtime, latitude, longitude, 0)
+        az[idx] = solar_angles[0]
+        sza[idx] = solar_angles[1]
+
+    return month, day, hour, minutes, time, time_bounds, sza, az
 
 
 def derive_times(dataframe, month, day):
@@ -89,6 +94,39 @@ def derive_times(dataframe, month, day):
             True)
 
 
+def grl_time(args, dataframe, longitude, latitude):
+    seconds_in_15min = 15*60
+    # dtime_1970, tz = common.time_common(args.tz)
+    num_rows = dataframe['year'].size
+
+    month, day, time, time_bounds, sza, az = ([0] * num_rows for _ in range(6))
+
+    hour = (dataframe['hour_mult_100']/100).astype(int)
+    minutes = (((dataframe['hour_mult_100']/100) % 1) * 100).astype(int)
+    temp_dtime = pd.to_datetime(dataframe['year']*1000 + dataframe['day_of_year'].astype(int), format='%Y%j')
+
+    dataframe['hour'] = hour
+    dataframe['minutes'] = minutes
+    dataframe['dtime'] = temp_dtime
+
+    dataframe['dtime'] = pd.to_datetime(dataframe.dtime)
+    dataframe['dtime'] += pd.to_timedelta(dataframe.hour, unit='h')
+    dataframe['dtime'] += pd.to_timedelta(dataframe.minutes, unit='m')
+
+    time = (dataframe['dtime'] - datetime(1970, 1, 1)) / np.timedelta64(1, 's') - seconds_in_15min
+    time_bounds = [(i-seconds_in_15min, i+seconds_in_15min) for i in time]
+
+    month = pd.DatetimeIndex(dataframe['dtime']).month.values
+    day = pd.DatetimeIndex(dataframe['dtime']).day.values
+
+    for idx in range(num_rows):
+        solar_angles = sunposition.sunpos(dataframe['dtime'][idx], latitude, longitude, 0)
+        az[idx] = solar_angles[0]
+        sza[idx] = solar_angles[1]
+
+    return month, day, hour, minutes, time, time_bounds, sza, az
+
+
 def imau2nc(args, input_file, output_file, stations):
     with open(input_file) as stream:
         line = stream.readline()
@@ -110,29 +148,44 @@ def imau2nc(args, input_file, output_file, stations):
     common.log(args, 2, 'Retrieving latitude, longitude and station name')
     latitude, longitude, station_name = get_station(args, input_file, stations)
 
-    common.log(args, 3, 'Calculating time and sza')
-    hour, month, day, time, time_bounds, sza = get_time_and_sza(
-        args, df, longitude, latitude)
+    if sub_type == 'imau/grl':
+        month, day, hour, minutes, time, time_bounds, sza, az = grl_time(
+            args, df, longitude, latitude)
+
+    elif sub_type == 'imau/ant':
+        common.log(args, 3, 'Calculating time and sza')
+        month, day, hour, minutes, time, time_bounds, sza, az = get_time_and_sza(
+            args, df, longitude, latitude)
 
-    if args.no_drv_tm:
-        pass
-    else:
         common.log(args, 5, 'Calculating month and day')
         derive_times(df, month, day)
-        ds['hour'] = 'time', hour
-        ds['month'] = 'time', month
-        ds['day'] = 'time', day
-
+    
+    ds['month'] = 'time', month
+    ds['day'] = 'time', day
+    ds['hour'] = 'time', hour
+    ds['minutes'] = 'time', minutes
     ds['time'] = 'time', time
     ds['time_bounds'] = ('time', 'nbnd'), time_bounds
     ds['sza'] = 'time', sza
+    ds['az'] = 'time', az
     ds['station_name'] = tuple(), station_name
     ds['latitude'] = tuple(), latitude
     ds['longitude'] = tuple(), longitude
 
+    if args.rigb:
+        common.log(args, 6, 'Detecting clear days')
+        clr_df = clearsky.main(ds, args)
+
+        if not clr_df.empty:
+            common.log(args, 7, 'Calculating tilt angle and direction')
+            ds = tilt_angle.main(ds, latitude, longitude, clr_df, args)
+
+            common.log(args, 8, 'Calculating corrected_fsds')
+            ds = fsds_adjust.main(ds, args)
+
     comp_level = args.dfl_lvl
 
     common.load_dataset_attributes(sub_type, ds, args)
-    encoding = common.get_encoding(sub_type, common.get_fillvalue(args), comp_level)
+    encoding = common.get_encoding(sub_type, common.get_fillvalue(args), comp_level, args)
 
     common.write_data(args, ds, output_file, encoding)
