@@ -7,12 +7,12 @@ import sys
 
 try:
     from jaws import gcnet2nc, promice2nc, aaws2nc, imau2nc, scar2nc, common, analysis
-except ImportError:
+except:
     import gcnet2nc, promice2nc, aaws2nc, imau2nc, scar2nc, common, analysis
 
 try:
     from jaws.common import jaws_version
-except ImportError:
+except:
     from common import jaws_version
 
 
@@ -107,6 +107,9 @@ def get_parser():
     parser.add_argument(
         '-m', '--anl_mth', '--analysis_month',
         help = 'Month you want to select', type = int)
+    parser.add_argument(
+        '--rigb',
+        help='Correct tilt angle and direction', action="store_true")
 
     return parser
 
@@ -131,8 +134,9 @@ def get_stations():
             raise RuntimeError(errmsg)
         name, lon, lat, name2 = match.groups()
         lon, lat = float(lon), float(lat)
+        name = name.strip()
         name2 = name2.strip()
-        value = [lon, lat, name2] if name2 else [lon, lat]
+        value = [lon, lat, name] if name2 else [lon, lat]
         ordered[name.strip()] = value
 
     return ordered
